==> HostCMS-6.1.7.tar: modules/module/i18n/en.php <==
<?php
/**
 * Modules.
 *
 * @package HostCMS 6\Module
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2013 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Modules',
	'menu' => 'Modules',
	'tab_attribute' => 'Parameters',
	'tab_parameters' => 'Module setting',
	'modules_add_success' => 'Module added successfully!',
	'edit_success' => 'Module modified successfully!',
	'modules_add_error_path1' => 'Error! Module with this path already exists in database.',
	'modules_add_error_path2' => 'Error! Path to module cannot be empty.',
	'modules_add_error_path3' => 'Error while creating module folder! You may have specified an invalid path to module folder.',
	'modules_add_error_create_module_file' => 'Error! Module file has not been created!',
	'modules_add_error_create_config_dir' => 'Error! Folder for module settings file has not been created!',
	'markDeleted_success' => 'Module deleted successfully!',
	'modules_deletes_message' => 'Modules deleted successfully!',
	'apply_success' => 'Information modified successfully!',
	'changeActive_success' => 'Information modified successfully!',
	'changeIndexing_success' => 'Indexing modified successfully!',
	'modules_add_form_title' => 'Add module information',
	'modules_edit_form_title' => 'Edit module information',
	'modules_show_modules_link' => 'Modules',
	'id' => 'Id',
	'name' => '<acronym title="Module name">Module name</acronym>',
	'description' => '<acronym title="Additional module information">Module description</acronym>',
	'modules_add_form_params' => '<acronym title="PHP code containing module parameters. Called before initialization of module">PHP code containing module parameters</acronym>',
	'modules_add_form_status' => '<acronym title="Module activity checkbox. Deactivated modules cannot be initialized">Status</acronym>',
	'active' => 'Active',
	'indexing' => 'Index',
	'path' => '<acronym title="Folder name of module location. Modules are located in [Root folder] / modules / [module name]">Path to module</acronym>',
	'sorting' => '<acronym title="Field according to which module is sorted when initializing">Sorting order</acronym>',
	'modules_title' => 'Module',
	'modules_title_list' => 'Modules',
	'modules_add_link' => 'Add',
	'error_file_open' => 'Unable to open file ',
	'error_file_write' => 'Unable to write into file ',
	'modules_active_set' => 'Module "%s" activated',
	'modules_active_unset' => 'Module "%s" deactivated',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS-6.8.6.tar: modules/module/i18n/en.php <==
<?php
/**
 * Modules.
 *
 * @package HostCMS
 * @subpackage Module
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Modules',
	'menu' => 'Modules',
	'tab_attribute' => 'Parameters',
	'tab_parameters' => 'Module setting',
	'modules_add_success' => 'Module added successfully!',
	'edit_success' => 'Module modified successfully!',
	'modules_add_error_path1' => 'Error! Module with this path already exists in database.',
	'modules_add_error_path2' => 'Error! Path to module cannot be empty.',
	'modules_add_error_path3' => 'Error while creating module folder! You may have specified an invalid path to module folder.',
	'modules_add_error_create_module_file' => 'Error! Module file has not been created!',
	'modules_add_error_create_config_dir' => 'Error! Folder for module settings file has not been created!',
	'markDeleted_success' => 'Module deleted successfully!',
	'modules_deletes_message' => 'Modules deleted successfully!',
	'apply_success' => 'Information modified successfully!',
	'changeActive_success' => 'Status changed successfully!',
	'changeIndexing_success' => 'Indexing modified successfully!',
	'modules_add_form_title' => 'Add module information',
	'modules_edit_form_title' => 'Edit module information',
	'modules_show_modules_link' => 'Modules',
	'id' => 'ID',
	'name' => 'Module name',
	'description' => 'Module description',
	'modules_add_form_params' => '<acronym title="PHP code containing module parameters. Called before initialization of module">PHP code containing module parameters</acronym>',
	'active' => 'Active',
	'indexing' => 'Index',
	'path' => '<acronym title="Folder name of module location. Modules are located in [Root folder] / modules / [module name]">Path to module</acronym>',
	'sorting' => 'Sort',
	'modules_title' => 'Module',
	'modules_title_list' => 'Modules',
	'modules_add_link' => 'Add',
	'error_file_open' => 'Unable to open file ',
	'error_file_write' => 'Unable to write into file ',
	'modules_active_set' => 'Module "%s" activated',
	'modules_active_unset' => 'Module "%s" deactivated',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);
